@@ -1799,7 +1799,7 @@ pango_font_get_glyph_extents  (PangoFont      *font,
 	}
       if (logical_rect)
 	{
-	  logical_rect->x = logical_rect->y = 0;
+	  logical_rect->x = 0;
 	  logical_rect->y = - PANGO_UNKNOWN_GLYPH_HEIGHT * PANGO_SCALE;
 	  logical_rect->height = PANGO_UNKNOWN_GLYPH_HEIGHT * PANGO_SCALE;
 	  logical_rect->width = PANGO_UNKNOWN_GLYPH_WIDTH * PANGO_SCALE;
@@ -2457,9 +2457,8 @@ pango_font_face_is_synthesized (PangoFontFace  *face)
  * @face: a #PangoFontFace.
  *
  * Gets a name representing the style of this face among the
- * different faces in the #PangoFontFamily for the face. This
- * name is unique among all faces in the family and is suitable
- * for displaying to users.
+ * different faces in the #PangoFontFamily for the face. The
+ * name is suitable for displaying to users.
  *
  * Return value: the face name for the face. This string is
  *   owned by the face object and must not be modified or freed.
