@@ -36,7 +36,6 @@
 
 struct _PangoCoreTextFontPrivate
 {
-  PangoCoreTextFace *face;
   gpointer context_key;
 
   CTFontRef font_ref;
@@ -176,12 +175,16 @@ pango_core_text_font_create_hb_font (PangoFont *font)
 
   if (ctfont->priv->font_ref)
     {
+      const PangoMatrix *matrix;
       hb_font_t *hb_font;
+      double x_scale, y_scale;
       int size;
 
+      matrix = pango_core_text_font_key_get_matrix (ctfont->priv->key);
+      pango_matrix_get_font_scale_factors (matrix, &x_scale, &y_scale);
       size = pango_core_text_font_key_get_size (ctfont->priv->key);
       hb_font = hb_coretext_font_create (ctfont->priv->font_ref);
-      hb_font_set_scale (hb_font, size, size);
+      hb_font_set_scale (hb_font, size / x_scale, size / y_scale);
 
       return hb_font;
     }
@@ -220,21 +223,12 @@ _pango_core_text_font_set_font_map (PangoCoreTextFont    *font,
   g_weak_ref_set((GWeakRef *) &priv->fontmap, fontmap);
 }
 
-void
-_pango_core_text_font_set_face (PangoCoreTextFont *ctfont,
-                                PangoCoreTextFace *ctface)
-{
-  PangoCoreTextFontPrivate *priv = ctfont->priv;
-
-  priv->face = ctface;
-}
-
 PangoCoreTextFace *
 _pango_core_text_font_get_face (PangoCoreTextFont *font)
 {
   PangoCoreTextFontPrivate *priv = font->priv;
 
-  return priv->face;
+  return pango_core_text_font_map_find_face (PANGO_CORE_TEXT_FONT_MAP (priv->fontmap), priv->key);
 }
 
 gpointer
