@@ -97,11 +97,11 @@ print_attribute (PangoAttribute *attr, GString *string)
   switch (attr->klass->type)
     {
     case PANGO_ATTR_LANGUAGE:
-      g_string_append_printf (string, "%s", pango_language_to_string (((PangoAttrLanguage *)attr)->value));
+      g_string_append (string, pango_language_to_string (((PangoAttrLanguage *)attr)->value));
       break;
     case PANGO_ATTR_FAMILY:
     case PANGO_ATTR_FONT_FEATURES:
-      g_string_append_printf (string, "%s", ((PangoAttrString *)attr)->value);
+      g_string_append (string, ((PangoAttrString *)attr)->value);
       break;
     case PANGO_ATTR_STYLE:
     case PANGO_ATTR_WEIGHT:
@@ -125,20 +125,33 @@ print_attribute (PangoAttribute *attr, GString *string)
       g_string_append_printf (string, "%d", ((PangoAttrInt *)attr)->value);
       break;
     case PANGO_ATTR_FONT_DESC:
-      g_string_append_printf (string, "%s", pango_font_description_to_string (((PangoAttrFontDesc *)attr)->desc));
+      {
+        char *text = pango_font_description_to_string (((PangoAttrFontDesc *)attr)->desc);
+        g_string_append (string, text);
+        g_free (text);
+      }
       break;
     case PANGO_ATTR_FOREGROUND:
     case PANGO_ATTR_BACKGROUND:
     case PANGO_ATTR_UNDERLINE_COLOR:
     case PANGO_ATTR_OVERLINE_COLOR:
     case PANGO_ATTR_STRIKETHROUGH_COLOR:
-      g_string_append_printf (string, "%s", pango_color_to_string (&((PangoAttrColor *)attr)->color));
+      {
+        char *text = pango_color_to_string (&((PangoAttrColor *)attr)->color);
+        g_string_append (string, text);
+        g_free (text);
+      }
       break;
     case PANGO_ATTR_SHAPE:
       g_string_append_printf (string, "shape");
       break;
     case PANGO_ATTR_SCALE:
-      g_string_append_printf (string,"%f", ((PangoAttrFloat *)attr)->value);
+      {
+        char val[20];
+
+        g_ascii_formatd (val, 20, "%f", ((PangoAttrFloat *)attr)->value);
+        g_string_append (string, val);
+      }
       break;
     default:
       g_assert_not_reached ();
